package com.chelvc.cloud.chelvc;

import com.chelvc.cloud.admin.AdminServer;
import com.chelvc.cloud.maintain.MaintainServer;
import com.chelvc.cloud.user.server.UserServer;
import com.chelvc.cloud.vehicle.server.VehicleServer;
import com.chelvc.framework.base.config.BeanFullnameGenerator;
import com.chelvc.framework.base.config.MultiserverMvcConfigurer;
import com.chelvc.framework.database.interceptor.DynamicDatasourceInterceptor;
import com.chelvc.framework.nacos.config.MultiserverNacosConfigurer;
import org.mybatis.spring.annotation.MapperScan;
import org.springframework.boot.SpringApplication;
import org.springframework.boot.autoconfigure.SpringBootApplication;
import org.springframework.cloud.client.discovery.EnableDiscoveryClient;
import org.springframework.cloud.openfeign.EnableFeignClients;
import org.springframework.context.annotation.ComponentScan;
import org.springframework.context.annotation.FilterType;
import org.springframework.context.annotation.Import;

/**
 * 服务启动类
 *
 * @author Woody
 * @date 2021/10/20
 */
@EnableDiscoveryClient
@EnableFeignClients(basePackages = "com.chelvc")
@MapperScan(basePackages = "com.chelvc.cloud.**.dao", nameGenerator = BeanFullnameGenerator.class)
@SpringBootApplication(scanBasePackages = "com.chelvc", nameGenerator = BeanFullnameGenerator.class)
@ComponentScan(basePackages = "com.chelvc",
        nameGenerator = BeanFullnameGenerator.class,
        excludeFilters = {@ComponentScan.Filter(type = FilterType.ASSIGNABLE_TYPE, classes = {
                UserServer.class,
                AdminServer.class,
                VehicleServer.class,
                MaintainServer.class
        })})
@Import({MultiserverMvcConfigurer.class, MultiserverNacosConfigurer.class, DynamicDatasourceInterceptor.class})
public class Server {
    public static void main(String[] args) {
        SpringApplication.run(Server.class);
    }
}
